rekha.plots.HeatmapPlot
=======================

.. currentmodule:: rekha.plots

.. autoclass:: HeatmapPlot

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~HeatmapPlot.add_annotation
      ~HeatmapPlot.get_axes
      ~HeatmapPlot.save
      ~HeatmapPlot.save_all_formats
      ~HeatmapPlot.show
      ~HeatmapPlot.show_legend
      ~HeatmapPlot.update_layout
   
   

   
   
   